@@ -8,16 +8,14 @@ from telescope_sdk.common import Location, IngestedDataType
 
 
 class CompanyType(Enum):
-    PUBLIC = "PUBLIC"
-    PRIVATE = "PRIVATE"
-    SUBSIDIARY = "SUBSIDIARY"
-    BRANCH = "BRANCH"
-    JOINT_VENTURE = "JOINT_VENTURE"
-    PARTNERSHIP = "PARTNERSHIP"
+    SOLE_PROPRIETORSHIP = "SOLE_PROPRIETORSHIP"
+    PUBLIC_COMPANY = "PUBLIC_COMPANY"
     GOVERNMENT_AGENCY = "GOVERNMENT_AGENCY"
-    NON_PROFIT = "NON_PROFIT"
-    SELF_EMPLOYED = "SELF_EMPLOYED"
-    OTHER = "OTHER"
+    PRIVATELY_HELD = "PRIVATELY_HELD"
+    PARTNERSHIP = "PARTNERSHIP"
+    SELF_EMPLOYED = "SELF-EMPLOYED"
+    NONPROFIT = "NONPROFIT"
+    EDUCATIONAL_INSTITUTION = "EDUCATIONAL_INSTITUTION"
 
 
 @dataclass_json
@@ -45,9 +43,10 @@ class Company(IngestedDataType):
     industry: Optional[str] = None
     categories: Optional[list[str]] = None
     specialties: Optional[list[str]] = None
-    company_type: Optional['CompanyType'] = None
-    company_size_range: Optional['CompanySizeRange'] = None
+    company_type: Optional[CompanyType] = None
+    company_size_range: Optional[CompanySizeRange] = None
     company_size_on_linkedin: Optional[int] = None
     founded_year: Optional[int] = None
     hq: Optional[Location] = None
-    locations: Optional[list['Location']] = None
+    locations: Optional[list[Location]] = None
+    last_enriched_at: Optional[str] = None
