@@ -15,7 +15,7 @@ class Prospect(UserFacingDataType):
     first_name: str
     last_name: str
     company_name: str
-    outreach_history: list[SequenceStep]
+    sequence_step_history: list[SequenceStep]
     job_title: Optional[str] = None
     email: Optional[str] = None
     average_sentiment: Optional[float] = None
